import styled from 'styled-components'
import { th } from '@pubsweet/ui-toolkit'

export const PreviewPage = styled.div`
  display: flex;
  justify-content: center;
  align-items: stretch;
  height: calc(100% - (${th('gridUnit')} * 20.125));
  background-color: ${th('colorBackground')};

  @media screen and (max-width: 870px) {
    flex-wrap: wrap;
    min-height: 0;
    height: auto;
    align-items: center;
  }
`
export const PreviewPanel = styled.div`
  flex: 1 1 1000px;
  height: 100%;
  max-width: 100%;
  min-width: 0;
  & > div {
    width: 100%;
    max-width: 1000px;
    margin: 0 0 0 auto;
    height: 100%;
    & > div {
      padding: 0 calc(${th('gridUnit')} * 2);
      &:last-child {
        height: calc(100% - (${th('gridUnit')} * 12));
        padding-bottom: calc(${th('gridUnit')} * 2);
        max-width: 100%;
      }
    }
  }
  @media screen and (max-width: 870px) {
    height: auto;
    & > div {
      height: auto;
    }
  }
`
export const EditPanel = styled.div`
  flex: 1 1 500px;
  & > div {
    height: 100%;
    overflow: auto;
    width: 100%;
    max-width: 500px;
    margin: 0 auto 0 0;
    border: ${th('borderWidth')} ${th('borderStyle')} ${th('colorBorder')};
    border-top: 0;
    border-bottom: 0;
    background-color: ${th('colorTextReverse')};
    padding-bottom: calc(${th('gridUnit')} * 3);
    & > div:first-child {
      padding-left: calc(${th('gridUnit')} * 3);
    }
    @media screen and (max-width: 870px) {
      max-width: 100%;
    }
  }
`
export const PanelHeader = styled.div`
  height: calc(${th('gridUnit')} * 10);
  display: flex;
  align-items: flex-end;
`
export const PanelContent = styled.div`
  .editor-wrapper,
  .annotator,
  .pdf-viewer,
  #html-preview {
    box-sizing: border-box;
    height: 100%;
    @media screen and (max-width: 870px) {
      height: 80vh;
    }
  }
  .pdf-viewer-pane {
    overflow: auto;
    height: calc(100% - (${th('gridUnit')} * 3));
    padding: calc(${th('gridUnit')} / 2) 0;
  }
  #html-preview {
    overflow: auto;
    background-color: ${th('colorTextReverse')};
    border: ${th('borderWidth')} ${th('borderStyle')} ${th('colorBorder')};
  }
`
export const SectionHeader = styled.div`
  display: flex;
  align-items: center;
  justify-content: space-between;
  background-color: ${th('colorBackgroundHue')};
  min-height: calc(${th('gridUnit')} * 6);
  padding: ${th('gridUnit')} calc(${th('gridUnit')} * 3);
  border: ${th('borderWidth')} ${th('borderStyle')} ${th('colorBorder')};
  border-right: 0;
  border-left: 0;
  & > * {
    margin: 0;
  }
  @media screen and (max-width: 870px) {
    padding: ${th('gridUnit')} calc(${th('gridUnit')} * 4);
  }
`
export const SectionContent = styled.div`
  max-width: 100%;
  & > * {
    padding: ${th('gridUnit')} calc(${th('gridUnit')} * 3);
  }
`
