if (process.env.NODE_ENV !== 'production') {
  require('dotenv').load()
}

const path = require('path')
const logger = require('winston')

module.exports = {
  schema: {},
  authsome: {
    mode: path.resolve(__dirname, 'authsome.js'),
    teams: {
      seniorEditor: {
        name: 'Senior Editors',
      },
      handlingEditor: {
        name: 'Handling Editors',
      },
      managingEditor: {
        name: 'Managing Editors',
      },
      reviewer: {
        name: 'Reviewer',
      },
    },
  },
  pubsweet: {},
  mailer: {
    from: 'helpdesk@europepmc.org',
    path: `${__dirname}/mailer`,
    transport: {
      sendmail: true,
    },
  },
  'pubsweet-server': {
    db: {
      port: 5432,
    },
    port: 3000,
    logger,
    uploads: 'uploads',
    graphiql: true,
    enableExperimentalGraphql: true,
    typeDefs: `
      extend type User {
        name: String
      }

      extend type Team {
        group: String
      }

      extend type Collection {
        collectionType: String
        created: String
        title: String
        status: String
        reviewers: [CollectionReviewer]
      }

      type CollectionReviewer {
        id: String!
        user: String!
      }

      extend type Fragment {
        created: String
        version: Int
        submitted: String
        source: String
        metadata: VersionMetadata
        declarations: VersionDeclaration
        suggestions: VersionSuggestionGroup
        files: VersionFileGroup
        notes: VersionNotes
        reviewers: [ReviewerMeta]
        # TODO
        #lock: VersionLock
        #decision: VersionDecision
      }
      type VersionMetadata {
        title: String
        abstract: String
        articleType: String
        articleSection: [String]
        authors: [String]
        keywords: [String]
      }
      type VersionDeclaration {
        #TODO make these boolean?
        openData: String
        previouslySubmitted: String
        openPeerReview: String
        streamlinedReview: String
        researchNexus: String
        preregistered: String
      }
      type VersionSuggestionGroup {
        reviewers: VersionSuggestions
        editors: VersionSuggestions
      }
      type VersionSuggestions {
        suggested: [String]
        opposed: [String]
      }
      type VersionFileGroup {
        manuscript: VersionFile
        supplementary: [VersionFile]
      }
      type VersionFile {
        name: String!
        type: String
        size: Int
        url: String
      }
      type VersionNotes {
        fundingAcknowledgement: String
        specialInstructions: String
      }
      type ReviewerMeta {
        id: String
        reviewer: String
        status: String
        _reviewer: CollectionReviewer
        _user: User
      }
    `,
  },
  'pubsweet-client': {
    API_ENDPOINT: '/api',
    'login-redirect': '/',
    'redux-log': false,
  },
  'password-reset': {
    url:
      `${process.env.PUBSWEET_URL}password-reset/` ||
      'http://localhost:3000/password-reset',
    sender: process.env.PUBSWEET_SENDER || 'dev@example.com',
  },
  'pubsweet-component-ink-backend': {
    inkEndpoint:
      process.env.INK_ENDPOINT || 'http://inkdemo-api.coko.foundation/',
    email: process.env.INK_USERNAME,
    password: process.env.INK_PASSWORD,
    maxRetries: 500,
    recipes: {
      'editoria-typescript': '2',
    },
  },
  'pubsweet-component-aws-s3': {
    secretAccessKey: process.env.AWS_S3_SECRET_KEY,
    accessKeyId: process.env.AWS_S3_ACCESS_KEY,
    region: process.env.AWS_S3_REGION,
    bucket: process.env.AWS_S3_BUCKET,
    validations: path.resolve(__dirname, 'upload-validations.js'),
  },
  'pubsweet-component-minio': {
    accessKeyId: process.env.MINIO_ACCESS_KEY,
    secretAccessKey: process.env.MINIO_SECRET_KEY,
    endPoint: process.env.MINIO_ENDPOINT,
    port: process.env.MINIO_PORT,
    secure: process.env.MINIO_SECURITY === 'true',
    bucket: process.env.MINIO_BUCKET,
    uploads: process.env.MINIO_UPLOADS_FOLDER_NAME,
  },
  publicKeys: ['pubsweet-client', 'authsome', 'validations'],
  elife: {
    api: {
      url: 'localhost',
    },
  },
  login: {
    enableMock: false,
  },
  pageSize: 50,
  manuscript: {
    status: {
      initial: 'INITIAL',
    },
  },
  user: {
    identity: {
      default: 'local',
    },
  },
}
